[devel] apache-1.3.41rusPL30.23-alt6: Sisyphus/i586 test rebuild failed

Michael Shigorin mike на osdn.org.ua
Ср Май 13 21:50:12 MSD 2009


On Fri, May 08, 2009 at 12:44:38AM +0400, QA Team Robot wrote:
> Package: apache-1.3.41rusPL30.23-alt6
> htpasswd.c:101: error: conflicting types for 'getline'
> /usr/include/stdio.h:653: note: previous declaration of 'getline' was here

Лёш, достаточно переименовать этот скорее всего внутренний
getline() во что-то ещё, как сделали в ядре и ряде других мест.

-- 
 ---- WBR, Michael Shigorin <mike на altlinux.ru>
  ------ Linux.Kiev http://www.linux.kiev.ua/
----------- следующая часть -----------
diff -Naur strongswan-4.2.14-orig/src/libfreeswan/optionsfrom.c strongswan-4.2.14/src/libfreeswan/optionsfrom.c
--- strongswan-4.2.14-orig/src/libfreeswan/optionsfrom.c	2008-12-23 06:24:06 +0000
+++ strongswan-4.2.14/src/libfreeswan/optionsfrom.c	2009-05-13 14:29:08 +0000
@@ -31,7 +31,7 @@
 
 static const char *dowork(const char *, int *, char ***, int);
 static const char *getanarg(FILE *, struct work *, char **);
-static char *getline(FILE *, char *, size_t);
+static char *parseline(FILE *, char *, size_t);
 
 /*
  - optionsfrom - add some options, taken from a file, to argc/argv
@@ -149,7 +149,7 @@
 	char *endp;
 
 	while (w->pending == NULL) {	/* no pending line */
-		if ((w->line = getline(f, w->buf, sizeof(w->buf))) == NULL)
+		if ((w->line = parseline(f, w->buf, sizeof(w->buf))) == NULL)
 			return "error in line read";	/* caller checks EOF */
 		if (w->line[0] != '#' &&
 				*(w->line + strspn(w->line, " \t")) != '\0')
@@ -171,7 +171,7 @@
 			if (*linep == NULL)
 				return "out of memory for new line";
 			strcpy(*linep, p);
-		} else			/* getline already malloced it */
+		} else			/* parseline already malloced it */
 			*linep = p;
 		return NULL;
 	}
@@ -203,10 +203,10 @@
 }
 
 /*
- - getline - read a line from the file, trim newline off
+ - parseline - read a line from the file, trim newline off
  */
 static char *			/* pointer to line, NULL for eof/error */
-getline(f, buf, bufsize)
+parseline(f, buf, bufsize)
 FILE *f;
 char *buf;			/* buffer to use, if convenient */
 size_t bufsize;			/* size of buf */


Подробная информация о списке рассылки Devel